Claude MPM Socket.IO Dashboard

# 🚀 Claude MPM Monitor

● Disconnected
--
--ms
0
Events
0
Per Min
0
Types
0
Errors
Session:
Working Dir:
Loading...
Session:

##### 📊 Structured Data

Click on an event to view structured data

Data is organized by event type

Connect to Socket.IO server to see events...
No agent events found...
No tool events found...
No file operations found...
Nodes: 0 Active: 0 Depth: 0
📁 Project Root
🎯 PM Session
📝 Todo Item
🤖 Agent
🔧 Tool